## $Id: contracts.py 12571 2015-02-09 08:30:13Z henrik $
##
## Copyright (C) 2014 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""
Customer contract components.
"""

import grok
from zope.component.interfaces import IFactory
from zope.interface import implementedBy
from waeup.ikoba.utils.helpers import attrs_to_fields
from waeup.ikoba.customers.interfaces import ICustomerNavigation
from waeup.ikoba.customers.contracts import ContractBase
from ikobacustom.pcn.interfaces import MessageFactory as _
from ikobacustom.pcn.customers.interfaces import (
    IRONContract,
    IRONContractEdit,
    IRONContractProcess,
    IRONContractOfficialUse,
    IROPContract,
    IROPContractEdit,
    IROPContractProcess, 
    IROPContractOfficialUse,
    IRPRContract,
    IRPRContractEdit,
    IRPRContractProcess,
    IRPRContractOfficialUse,
    )


class RONContract(ContractBase):
    """This is a sample contract.
    """

    grok.implements(
        IRONContractProcess,
        IRONContract,
        IRONContractEdit,
        ICustomerNavigation)

    contract_category = 'ron'

    form_fields_interface = IRONContract

    edit_form_fields_interface = IRONContractEdit

    ou_form_fields_interface = IRONContractOfficialUse

    check_docs_interface = IRONContract

RONContract = attrs_to_fields(RONContract)


class RONContractFactory(grok.GlobalUtility):
    """A factory for contracts.
    """
    grok.implements(IFactory)
    grok.name(u'waeup.RONContract')
    title = u"Create a new license contract.",
    description = u"This factory instantiates new contract instances."

    def __call__(self, *args, **kw):
        return RONContract(*args, **kw)

    def getInterfaces(self):
        return implementedBy(RONContract)


class ROPContract(ContractBase):
    """This is a sample contract.
    """

    grok.implements(
        IROPContractProcess,
        IROPContract,
        IROPContractEdit,
        ICustomerNavigation)

    contract_category = 'rop'

    form_fields_interface = IROPContract

    edit_form_fields_interface = IROPContractEdit

    ou_form_fields_interface = IROPContractOfficialUse

    check_docs_interface = IROPContract

ROPContract = attrs_to_fields(ROPContract)


class ROPContractFactory(grok.GlobalUtility):
    """A factory for contracts.
    """
    grok.implements(IFactory)
    grok.name(u'waeup.ROPContract')
    title = u"Create a new license contract.",
    description = u"This factory instantiates new contract instances."

    def __call__(self, *args, **kw):
        return ROPContract(*args, **kw)

    def getInterfaces(self):
        return implementedBy(ROPContract)


class RPRContract(ContractBase):
    """Registration in the Provisional Register contract.
    """

    grok.implements(
        IRPRContractProcess,
        IRPRContract,
        IRPRContractEdit,
        ICustomerNavigation)

    contract_category = 'rpr'

    form_fields_interface = IRPRContract

    edit_form_fields_interface = IRPRContractEdit

    ou_form_fields_interface = IRPRContractOfficialUse

    check_docs_interface = IRPRContract

RPRContract = attrs_to_fields(RPRContract)


class RPRContractFactory(grok.GlobalUtility):
    """A factory for contracts.
    """
    grok.implements(IFactory)
    grok.name(u'waeup.RPRContract')
    title = u"Create a new license contract.",
    description = u"This factory instantiates new contract instances."

    def __call__(self, *args, **kw):
        return RPRContract(*args, **kw)

    def getInterfaces(self):
        return implementedBy(RPRContract)
